@@ -21,7 +21,7 @@
 <body>
 	<div id="novaWrapper">		<div id="clearHeader">
 			<div id="logo">
-									 <img src="/eclipse.org-common/themes/Nova/images/eclipse.png" alt="Eclipse.org"/>
+									 <img src="/eclipse.org-common/themes/Nova/images/eclipse-800x426.png" alt="Eclipse.org" width="171" height="91"/>
 							</div>
 <div id="otherSites"><div id="sites"><ul id="sitesUL">
 <li><a href='//marketplace.eclipse.org'><img alt="Eclipse Marketplace" src="//dev.eclipse.org/custom_icons/marketplace.png"/>&nbsp;<span>Eclipse Marketplace</span></a></li>
@@ -312,6 +312,6 @@ its rights to a jury trial in any resulting litigation. </p><br/>
 <li><a href="/legal/copyright.php">Copyright Agent</a></li>
 <li><a href="/legal/">Legal</a></li>
 <li><a href="/org/foundation/contact.php">Contact Us</a></li></ul>
-			<span id="copyright">Copyright &copy; 2013 The Eclipse Foundation. All Rights Reserved.</span>
+			<span id="copyright">Copyright &copy; 2014 The Eclipse Foundation. All Rights Reserved.</span>
 		</div>
 	</div> </body></html>
\ No newline at end of file
